/*
 * Copyright (c) 2015 Samsung Electronics Co., Ltd
 *
 * Licensed under the Flora License, Version 1.1 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://floralicense.org/license/
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#if !defined(_VIEW_H)
#define _VIEW_H

#define ITEM_LAYOUT_WIDTH 360
#define ITEM_LAYOUT_HEIGHT 360
#define ITEM_COUNT 3
#define ICON_WIDTH (216 + 25)
#define ICON_HEIGHT 360
#define MAIN_MORE_ITEM_MAX 2
#define DETAIL_MORE_ITEM_MAX 1
#define DATA_KEY_BOX "box"
#define DATA_KEY_INDEX "index"
#define DATA_KEY_BOTTOM_BUTTON "bottom_button"
#define BUF_LEN 1024

typedef struct {
	char *style;
	char *title;
	char *date;
	char *stren;
	char *detail_date;
	char *detail_time;
	char *duration;
	Elm_Object_Item *item;
	char *absolute_file_path;
} voice_list_item_info;

/*
 * Create a view
 */
void view_create(void);
void view_destroy(void);
void view_destroy_layout(Evas_Object *layout);

Evas_Object *view_get_win(void);
Evas_Object *view_get_naviframe(void);
Evas_Object *view_get_base_layout(void);

void view_set_image(Evas_Object *parent, const char *part_name, const char *image_path);
void view_set_text(Evas_Object *parent, const char *part_name, const char *text);
void view_create_naviframe(Evas_Object *parent);
Elm_Object_Item *view_push_item_to_naviframe(Evas_Object *nf, Evas_Object *item, Elm_Naviframe_Item_Pop_Cb pop_cb, void *user_data);
void view_pop_item_from_naviframe(void);
void view_create_more_item(Evas_Object *parent, int index, char *name, char *sub_name, char *image_path);
Evas_Object *view_set_more_button(Evas_Object *parent, const char *part_name, Evas_Smart_Cb item_selected, void *user_data);
Evas_Object *view_create_circle_genlist(Evas_Object *parent);
Elm_Object_Item *view_append_item_to_genlist(Evas_Object *genlist, const char *style, const void *gen_data, Evas_Smart_Cb clicked_cb, const void *user_data);
void view_destroy_voice_list_genlist();
Eina_List *view_get_voice_list(void);
Evas_Object *view_create_win(const char *pkg_name);
Evas_Object *view_create_conformant_without_indicator(Evas_Object *parent);
Evas_Object *view_create_layout_for_conformant_by_theme(Evas_Object *parent, const char *class_name, const char *group_name, const char *style);
Evas_Object *view_create_layout(Evas_Object *parent, const char *file_path, const char *group_name, Eext_Event_Cb cb_function, void *user_data);
Evas_Object *view_create_layout_by_theme(Evas_Object *parent, const char *class_name, const char *group_name, const char *style);
Evas_Object *view_create_layout_with_group(Evas_Object *parent, char *group_name);
Evas_Object *view_create_layout_no_content(Evas_Object *parent, char *title, char *detail, char *image_path);
void view_set_button(Evas_Object *parent, const char *part_name, const char *style, const char *image_path, const char *text,
		                Evas_Object_Event_Cb down_cb, Evas_Object_Event_Cb up_cb, Evas_Smart_Cb clicked_cb, void *user_data);
void view_send_signal_to_edje(Evas_Object *layout, const char *signal, const char *source);
void view_voice_memo_create();
void view_destroy_object_item(Elm_Object_Item *item);
void view_create_text_popup(Evas_Object *parent, double timeout, const char *text);

#endif
